@@ -43,9 +43,13 @@ import (
 	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/otel-logs"
 	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/otel-metrics"
 	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/sort"
+	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/ustack"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/params"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/runtime"
 	grpcruntime "github.com/inspektor-gadget/inspektor-gadget/pkg/runtime/grpc"
+
+	// Symbolizers (only client-side)
+	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/symbolizer/debuginfod"
 )
 
 type CommandMode string
@@ -124,11 +128,18 @@ func NewRunCommand(rootCmd *cobra.Command, runtime runtime.Runtime, hiddenColumn
 	initializedOperators := false
 
 	preRun := func(cmd *cobra.Command, args []string) error {
-		err := runtime.Init(runtimeGlobalParams)
-		if err != nil {
-			return fmt.Errorf("initializing runtime: %w", err)
+		// Skip runtime init if only -h/--help was specified.
+		// If an image name is given, we need to initialize the runtime
+		skipRuntimeInit := len(args) == 1 && (args[0] == "-h" || args[0] == "--help")
+
+		var err error
+		if !skipRuntimeInit {
+			err = runtime.Init(runtimeGlobalParams)
+			if err != nil {
+				return fmt.Errorf("initializing runtime: %w", err)
+			}
+			defer runtime.Close()
 		}
-		defer runtime.Close()
 
 		// set global operator flags from the config file
 		for o, p := range opGlobalParams {
@@ -486,6 +497,11 @@ nextParam:
 			desc += " [" + strings.Join(p.PossibleValues, ", ") + "]"
 		}
 
+		if p.AlternativeKey != "" {
+			cmd.PersistentFlags().Var(&Param{p}, p.AlternativeKey, desc)
+			cmd.PersistentFlags().MarkHidden(p.AlternativeKey)
+			desc += " (alias: " + p.AlternativeKey + ")"
+		}
 		flag := cmd.PersistentFlags().VarPF(&Param{p}, p.Key, p.Alias, desc)
 		if p.IsMandatory {
 			cmd.MarkPersistentFlagRequired(p.Key)
