@@ -66,6 +66,10 @@ import (
 	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/ustack"
 	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/wasm"
 
+	// Symbolizers (all)
+	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/symbolizer/debuginfod"
+	_ "github.com/inspektor-gadget/inspektor-gadget/pkg/symbolizer/symtab"
+
 	gadgetservice "github.com/inspektor-gadget/inspektor-gadget/pkg/gadget-service"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/gadget-service/api"
 	kubemanagertypes "github.com/inspektor-gadget/inspektor-gadget/pkg/operators/kubemanager/types"
