@@ -44,7 +44,7 @@ import (
 	oras_auth "oras.land/oras-go/v2/registry/remote/auth"
 
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/logger"
-	signatureverifier "github.com/inspektor-gadget/inspektor-gadget/pkg/signature-verifier"
+	"github.com/inspektor-gadget/inspektor-gadget/pkg/signature"
 )
 
 type AuthOptions struct {
@@ -61,9 +61,8 @@ type AllowedGadgetsOptions struct {
 }
 
 type VerifyOptions struct {
-	signatureverifier.VerifyOptions
-
 	VerifySignature bool
+	Verifier        *signature.SignatureVerifier
 }
 
 type ImageOptions struct {
@@ -206,7 +205,7 @@ func pullImage(ctx context.Context, targetImage reference.Named, imageStore oras
 	}
 
 	imageDigest := desc.Digest.String()
-	if err := signatureverifier.PullSigningInformation(ctx, repo, imageStore, imageDigest); err != nil {
+	if err := signature.PullSigningInformation(ctx, repo, imageStore, imageDigest); err != nil {
 		log.Warnf("error pulling signature: %v", err)
 		// it's not a requirement to have a signature for pulling the image
 		return &desc, nil
@@ -357,7 +356,7 @@ func ExportGadgetImages(ctx context.Context, dstFile string, images ...string) e
 			return fmt.Errorf("copying image to remote repository: %w", err)
 		}
 
-		err = signatureverifier.ExportSigningInformation(ctx, ociStore, dstStore, desc)
+		err = signature.ExportSigningInformation(ctx, ociStore, dstStore, desc)
 		if errors.Is(err, errdef.ErrNotFound) {
 			continue
 		}
@@ -857,7 +856,7 @@ func ensureImage(ctx context.Context, imageStore oras.Target, image string, imgO
 		return fmt.Errorf("creating remote repository: %w", err)
 	}
 
-	err = signatureverifier.Verify(ctx, repo, imageStore, imageRef, imgOpts.VerifyOptions.VerifyOptions)
+	err = imgOpts.Verifier.Verify(ctx, repo, imageStore, imageRef)
 	if err != nil {
 		return fmt.Errorf("verifying gadget signature %q: %w", image, err)
 	}
