@@ -30,6 +30,7 @@ import (
 	"sync"
 
 	"github.com/cilium/ebpf"
+	"github.com/cilium/ebpf/asm"
 	"github.com/cilium/ebpf/btf"
 	"github.com/cilium/ebpf/link"
 	ocispec "github.com/opencontainers/image-spec/specs-go/v1"
@@ -43,6 +44,7 @@ import (
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/gadget-service/api"
 	apihelpers "github.com/inspektor-gadget/inspektor-gadget/pkg/gadget-service/api-helpers"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/gadgets"
+	libpcap_compiler "github.com/inspektor-gadget/inspektor-gadget/pkg/libpcap-compiler"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/logger"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/networktracer"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/oci"
@@ -376,27 +378,59 @@ func (i *ebpfInstance) init(gadgetCtx operators.GadgetContext) error {
 			if len(parts) != 3 {
 				return fmt.Errorf("invalid section name %q", p.SectionName)
 			}
-			if parts[0] != "classifier" {
-				return fmt.Errorf("invalid section name %q", p.SectionName)
+
+			for idx := 0; idx < len(p.Instructions); idx++ {
+				inst := p.Instructions[idx]
+				name, ok := strings.CutPrefix(inst.Symbol(), packetFilterPrefix)
+				if !ok {
+					continue
+				}
+				filter := i.paramValues[packetFilterParam+"-"+name]
+
+				// If the name is empty, we'll use `pf` as the parameter name directly
+				if name == "" {
+					filter = i.paramValues[packetFilterParam]
+				}
+				if filter == "" {
+					i.logger.Debugf("skipping pcap filter %q at %d: no filter set", filter, idx)
+					continue
+				}
+				injectIdx := idx
+				i.logger.Debugf("injecting pcap filter %q at %d", filter, idx)
+				insns := p.Instructions
+				filterInsns, err := libpcap_compiler.CompileEbpf(filter, inst.Symbol())
+				if err != nil {
+					return fmt.Errorf("adding filter: %w", err)
+				}
+				filterInsns[0] = filterInsns[0].WithMetadata(insns[injectIdx].Metadata)
+				insns[injectIdx] = insns[injectIdx].WithMetadata(asm.Metadata{})
+				p.Instructions = append(insns[:injectIdx], append(filterInsns, insns[injectIdx:]...)...)
+
+				idx = injectIdx
 			}
 
-			var direction tchandler.AttachmentDirection
-
-			switch parts[1] {
-			case "ingress":
-				direction = tchandler.AttachmentDirectionIngress
-			case "egress":
-				direction = tchandler.AttachmentDirectionEgress
+			switch parts[0] {
 			default:
-				return fmt.Errorf("unsupported hook type %q", parts[1])
-			}
+				return fmt.Errorf("invalid section name %q (nclass)", p.SectionName)
+			case "classifier":
+				var direction tchandler.AttachmentDirection
 
-			handler, err := tchandler.NewHandler(direction)
-			if err != nil {
-				return fmt.Errorf("creating tc network tracer: %w", err)
-			}
+				switch parts[1] {
+				case "ingress":
+					direction = tchandler.AttachmentDirectionIngress
+				case "egress":
+					direction = tchandler.AttachmentDirectionEgress
+				default:
+					return fmt.Errorf("unsupported hook type %q", parts[1])
+				}
 
-			i.tcHandlers[p.Name] = handler
+				handler, err := tchandler.NewHandler(direction)
+				if err != nil {
+					return fmt.Errorf("creating tc network tracer: %w", err)
+				}
+
+				i.tcHandlers[p.Name] = handler
+			}
 		}
 	}
 
@@ -419,6 +453,10 @@ func (i *ebpfInstance) init(gadgetCtx operators.GadgetContext) error {
 		},
 	}
 
+	for name, m := range i.collectionSpec.Maps {
+		gadgetCtx.SetVar(operators.MapSpecPrefix+name, m)
+	}
+
 	return nil
 }
 
@@ -537,6 +575,34 @@ func (i *ebpfInstance) ExtraParams(gadgetCtx operators.GadgetContext) api.Params
 
 	// MapIter params
 	res = append(res, i.mapParams()...)
+
+	// Iterate over programs
+	filters := make(map[string]struct{})
+	for programName, program := range i.collectionSpec.Programs {
+		// check for packet filters
+		for _, inst := range program.Instructions {
+			name, ok := strings.CutPrefix(inst.Symbol(), packetFilterPrefix)
+			if !ok {
+				continue
+			}
+			if _, ok := filters[name]; ok {
+				continue
+			}
+			paramName := packetFilterParam + "-" + name
+			// if no name was given, use `pf` directly
+			if name == "" {
+				paramName = packetFilterParam
+			}
+
+			i.logger.Debugf("> program %q uses packet filter named %q", programName, name)
+			res = append(res, &api.Param{
+				Key:         paramName,
+				Description: fmt.Sprintf("packet filter %s", name),
+				TypeHint:    api.TypeString,
+			})
+			filters[name] = struct{}{}
+		}
+	}
 	return res
 }
 
@@ -700,6 +766,32 @@ func (i *ebpfInstance) Start(gadgetCtx operators.GadgetContext) error {
 		}
 	}
 
+	// Maps with a parameter _max_entries can have their size set at runtime.
+	// Example:
+	//     const volatile int mymap_max_entries = 1024;
+	//     GADGET_PARAM(mymap_max_entries);
+	//
+	//     struct {
+	//            __uint(type, BPF_MAP_TYPE_HASH);
+	//            __uint(key_size, sizeof(u32));
+	//            __uint(value_size, sizeof(u32));
+	//            __uint(max_entries, 0);
+	//     } mymap SEC(".maps");
+	for _, m := range i.collectionSpec.Maps {
+		maxEntriesStr := m.Name + "_max_entries"
+		v, ok := i.collectionSpec.Variables[maxEntriesStr]
+		if !ok {
+			continue
+		}
+		var maxEntries uint32
+		err := v.Get(&maxEntries)
+		if err != nil {
+			i.logger.Warnf("Getting map %q max_entries: %s", m.Name, err)
+			continue
+		}
+		m.MaxEntries = maxEntries
+	}
+
 	i.logger.Debugf("creating ebpf collection")
 
 	// check if the btfgen operator has stored the kernel types in the context
