@@ -8,8 +8,8 @@
 #include <bpf/bpf_core_read.h>
 #include <bpf/bpf_tracing.h>
 
-static __always_inline void prepare_socket_key(struct sockets_key *socket_key,
-					       struct sock *sock)
+static __always_inline void
+prepare_socket_key(struct gadget_socket_key *socket_key, struct sock *sock)
 {
 	struct inet_sock *inet_sock = (struct inet_sock *)sock;
 	BPF_CORE_READ_INTO(&socket_key->netns, sock, __sk_common.skc_net.net,
